@@ -6,6 +6,5 @@ from sky_api_client.entity.registry import EntityRegistry
 class EventFee(Entity):
     LIST_URL = '/event/v1/events/{id}/eventfees'
     CREATE_URL = '/event/v1/events/{id}/eventfees'
-    GET_URL = '/event/v1/events/{parent_id}/eventfees/{id}'
-    UPDATE_URL = '/event/v1/events/{parent_id}/eventfees/{id}'
-    DELETE_URL = '/event/v1/events/{parent_id}/eventfees/{id}'
+    UPDATE_URL = '/event/v1/eventfees/{id}'
+    DELETE_URL = '/event/v1/eventfees/{id}'
\ No newline at end of file
